@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.26 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.25 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.26 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -63,6 +63,13 @@ class SyL_ConfigActions extends SyL_Config
      * @param int
      */
     var $default_priority = 5;
+    /**
+     * ǥեȥ᥽å̾
+     * 
+     * @access protected
+     * @param string
+     */
+    var $default_method = 'execute';
     /**
      * ƥʥ̾
      * 
@@ -70,20 +77,6 @@ class SyL_ConfigActions extends SyL_Config
      * @var object
      */
     var $action_key = SYL_ACTION_KEY;
-    /**
-     * ե륭å奭
-     * 
-     * @access private
-     * @param string
-     */
-    var $action_cache_key = '__syL_action_cache';
-    /**
-     * ե륭åǡ
-     * 
-     * @access private
-     * @var array
-     */
-    var $action_cache_value = array();
 
     /**
      * XMLեβϽ
@@ -102,29 +95,30 @@ class SyL_ConfigActions extends SyL_Config
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
-                // åѥ᡼¸
-                $this->config[$this->action_cache_key] = $this->action_cache_value;
+                // ¹Խѹ
+                $this->changeActionOrder();
+                // ¹ԥ᥽å
+                $this->setPreAction();
+                // ¹ԥ᥽å
+                $this->setPostAction();
+                // 򥭥å岽
                 $cache->write($this->config);
-            } else {
-                // åѥ᡼
-                $this->action_cache_value = $this->config[$this->action_cache_key];
             }
-            // åѥ᡼
-            unset($this->config[$this->action_cache_key]);
         } else {
             // åѤʤ
             parent::parseXml();
+            // ¹Խѹ
+            $this->changeActionOrder();
+            // ¹ԥ᥽å
+            $this->setPreAction();
+            // ¹ԥ᥽å
+            $this->setPostAction();
         }
 
         if (!isset($this->config[$this->action_key])) {
             // б륢ޥåԥ󥰤¸ߤʤ
             trigger_error("[SyL error] Action mapping not found (" . $this->context->getActionFile() . ")", E_USER_ERROR);
         }
-
-        // ӥ塼פ򥻥å
-        $this->context->setViewType($this->action_cache_value['viewType']);
-        // 쥤̾򥻥å
-        $this->context->setLayoutName($this->action_cache_value['layoutName']);
     }
 
     /**
@@ -168,12 +162,20 @@ class SyL_ConfigActions extends SyL_Config
             // URLǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
             if (preg_match('/^' . $reg . '$/', $this->context->getActionFile(), $matches)) {
-                $name = $this->action_key;
+                $name  = $this->action_key;
+                // ǥեȥ
+                $class = $this->context->getClassName();
+                $file  = $this->context->getActionDir() . $this->context->getActionFile();
+                // ǥե¸Ƚ
+                if (!is_file($file)) {
+                    $class = SyL_Loader::convertClass(SYL_ACTION_BASE_CLASS);
+                    $file  = SYL_APP_LIB_DIR . SyL_Loader::convertPath(SYL_ACTION_BASE_CLASS);
+                }
                 // ݡͥȥѥ᡼
                 $this->config[$name] = array(
-                    'class'       => $this->context->getClassName(),
+                    'class'       => $class,
                     'type'        => 'action',
-                    'file'        => $this->context->getActionDir() . $this->context->getActionFile(),
+                    'file'        => $file,
                     'reference'   => true,
                     'priority'    => $this->default_priority, // ¹Խ
                     'constructor' => false, // 󥹥ȥ饯󥸥ե饰
@@ -181,47 +183,22 @@ class SyL_ConfigActions extends SyL_Config
                     'args'        => array() // 
                 );
 
-                // ̥
-                $pre_name = 'pre_' . $name;
-                $this->config[$pre_name] = $this->config[$name];
-                $this->config[$pre_name]['priority']--; // ¹Խ(1ʳᤤ)
-                $this->config[$pre_name]['event'][$this->event][] = $pre_name;
-
-                // ̥
-                $post_name = 'post_' . $name;
-                $this->config[$post_name] = $this->config[$name];
-                $this->config[$post_name]['priority']++; // ¹Խ(1ʳ٤)
-                $this->config[$post_name]['event'][$this->event][] = $post_name;
-
-                // ե뤬̵硢pre, postΤ߼¹
-                if (!is_file($this->context->getActionDir() . $this->context->getActionFile())) {
-                    $action_path  = '';
-                    $action_class = '';
-                    if (SYL_ACTION_BASE_CLASS) {
-                        $action_path  = SyL_Loader::convertPath(SYL_ACTION_BASE_CLASS);
-                        $action_class = SyL_Loader::convertClass(SYL_ACTION_BASE_CLASS);
-                    }
-                    if (is_file(SYL_APP_LIB_DIR . $action_path)) {
-                        $action_path  = SYL_APP_LIB_DIR . $action_path;
-                    } else if (is_file(SYL_PROJECT_LIB_DIR . $action_path)) {
-                        $action_path = SYL_PROJECT_LIB_DIR . $action_path;
-                    } else {
-                        $action_path = SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
-                    }
-                    $this->config[$pre_name]['file']   = $action_path;
-                    $this->config[$pre_name]['class']  = $action_class;
-                    $this->config[$post_name]['file']  = $action_path;
-                    $this->config[$post_name]['class'] = $action_class;
-                }
-
                 // ٥ȥʥ֥Ⱥ
                 $this->config[$name]['event'][$this->event][] = $name;
 
-                // ݡͥȥѥ᡼ʳ
-                $this->action_cache_value = array(
-                    'viewType'   => isset($attribute['viewType'])   ? $attribute['viewType']   : '', // ӥ塼
-                    'layoutName' => isset($attribute['layoutName']) ? $attribute['layoutName'] : ''  // 쥤
-                );
+                $method_name = '';
+                if (isset($attribute['method'])) {
+                    $method_name = 'method:' . str_replace('{action}', $this->context->getActionName(), $attribute['method']);
+                } else {
+                    // ᥽åɤΥǥե
+                    $method_name = 'method:' . $this->default_method;
+                }
+                // ᥽åɤΰϸ
+                $this->config[$name]['args'][$method_name] = array();
+                $this->config[$name]['args'][$method_name][] = 'component:true:data';
+                $this->config[$name]['args'][$method_name][] = 'component:true:context';
+
+                $this->config[$name]['event'][$this->event][] = $method_name; // ٥ȥ
             }
             break;
 
@@ -236,23 +213,14 @@ class SyL_ConfigActions extends SyL_Config
                 } else {
                     $method_name = 'setter:set' . ucfirst($attribute['name']) . ':false';
                 }
-                $prepost_method_name = '';
                 $this->config[$name]['event'][$this->event][] = $method_name;
                 $this->config[$name]['args'][$method_name]    = array();
                 break;
 
             case '/syl-actions/action/method':
-                $method_name = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
-                $this->config[$name]['args'][$method_name] = array();
+                $method_name = 'method:' . $attribute['name'];
                 $this->config[$name]['event'][$this->event][] = $method_name; // ٥ȥ
-
-                $pre_method_name = 'method:preExecute';
-                $this->config[$pre_name]['args'][$pre_method_name] = array();
-                $this->config[$pre_name]['event'][$this->event][]  = $pre_method_name; // ٥ȥ
-
-                $post_method_name = 'method:postExecute';
-                $this->config[$post_name]['args'][$post_method_name] = array();
-                $this->config[$post_name]['event'][$this->event][]   = $post_method_name; // ٥ȥ
+                $this->config[$name]['args'][$method_name] = array();
                 break;
 
             case '/syl-actions/action/setter/arg':
@@ -260,9 +228,7 @@ class SyL_ConfigActions extends SyL_Config
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                 $arg  = "{$type}:{$ref}:{$text}";
-                $this->config[$name]['args'][$method_name][]           = $arg;
-                $this->config[$pre_name]['args'][$pre_method_name][]   = $arg;
-                $this->config[$post_name]['args'][$post_method_name][] = $arg;
+                $this->config[$name]['args'][$method_name][] = $arg;
                 break;
 
            case '/syl-actions/action/components/component':
@@ -334,6 +300,85 @@ class SyL_ConfigActions extends SyL_Config
             }
         }
     }
+
+    /**
+     * ¹ԥ᥽åɤν֤ѹ
+     * ˥ݡͥȤΥ󥸥󤬤
+     *
+     * @access private
+     */
+    function changeActionOrder()
+    {
+        $name = $this->action_key;
+
+        // 󥸥̵ϥ롼
+        if (count($this->config[$name]['event'][$this->event]) <= 2) {
+            return;
+        }
+
+        $method = array_splice($this->config[$name]['event'][$this->event], 1, 1);
+        array_push($this->config[$name]['event'][$this->event], $method[0]);
+
+        // ϢνѹΤƬͤ
+        $main_args = array();
+        foreach ($this->config[$name]['args'] as $key => $arg) {
+            $main_args[$key] = $arg;
+            break;
+        }
+
+        array_shift($this->config[$name]['args']);
+        foreach ($main_args as $key => $arg) {
+            $this->config[$name]['args'][$key] = $arg;
+        } 
+    }
+
+
+    /**
+     * ¹᥽åɤ
+     *
+     * @access private
+     */
+    function setPreAction()
+    {
+        $name   = $this->action_key;
+        $method = 'method:pre' . ucfirst($this->default_method);
+        array_splice($this->config[$name]['event'][$this->event], 1, 0, $method);
+
+        // ϢνѹΤ¸
+        $main_args = array();
+        foreach ($this->config[$name]['args'] as $key => $arg) {
+            $main_args[$key] = $arg;
+        }
+
+        $args = array();
+        $args[0] = 'component:true:data';
+        $args[1] = 'component:true:context';
+
+        // preExecuteΤۤ˸ƤФ褦˽ѹ
+        $this->config[$name]['args'] = array();
+        $this->config[$name]['args'][$method] = $args;
+        foreach ($main_args as $key => $arg) {
+            $this->config[$name]['args'][$key] = $arg;
+        }
+    }
+
+    /**
+     * ¹Ը᥽åɤ
+     *
+     * @access private
+     */
+    function setPostAction()
+    {
+        $name   = $this->action_key;
+        $method = 'method:post' . ucfirst($this->default_method);
+        array_push($this->config[$name]['event'][$this->event], $method);
+
+        $args = array();
+        $args[0] = 'component:true:data';
+        $args[1] = 'component:true:context';
+
+        $this->config[$name]['args'][$method] = $args;
+    }
 }
 
 ?>
