@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.9 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.9 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -56,6 +56,13 @@ class SyL_ContextJs extends SyL_Context
      * @var object
      */
     var $request = null;
+    /**
+     * ӥ塼
+     * 
+     * @access protected
+     * @var string
+     */
+    var $view_type = 'js.default';
 
     /**
      * ꥯȥ֥Ȥ
@@ -187,6 +194,25 @@ class SyL_ContextJs extends SyL_Context
         return isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : null;
     }
 
+    /**
+     * PATH_INFOγURLȤƼ
+     *
+     * @access protected
+     * @param object ƥȥ֥
+     * @return array PATH_INFOγURL
+     */
+    function getUrlNames()
+    {
+        $pathinfo = $this->getPathInfo();
+        if (substr($pathinfo, -1) == '/') {
+            $pathinfo = substr($pathinfo, 0, -1);
+        } else {
+            $pathinfo = dirname($pathinfo);
+        }
+        // ǥ쥯ȥ
+        $urls = substr($pathinfo, 1); // Ƭ/׺
+        return (($urls !== false) && ($urls !== '')) ? explode('/', $urls) : array();
+    }
 }
 
 ?>
