@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextXmlrpc.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextXmlrpc.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,13 +42,20 @@ require_once 'SyL_ContextJs.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextXmlrpc.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextXmlrpc.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextXmlrpc extends SyL_ContextJs
 {
+    /**
+     * ӥ塼
+     * 
+     * @access protected
+     * @var string
+     */
+    var $view_type = 'xmlrpc';
 }
 
 ?>
