@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.17 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.17 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -101,6 +101,20 @@ class SyL_Router
      * @var string
      */
     var $action_class = '';
+    /**
+     * ӥ塼
+     *
+     * @access protected
+     * @var string
+     */
+    var $view_type = '';
+    /**
+     * 쥤̾
+     *
+     * @access protected
+     * @var string
+     */
+    var $layout_name = '';
 
     /**
      * 󥹥ȥ饯
@@ -190,6 +204,28 @@ class SyL_Router
         return $this->action_method;
     }
 
+    /**
+     * ӥ塼פ
+     *
+     * @access public
+     * @return string ӥ塼
+     */
+    function getViewType()
+    {
+        return $this->view_type;
+    }
+
+    /**
+     * 쥤̾
+     *
+     * @access public
+     * @return string 쥤̾
+     */
+    function getLayoutName()
+    {
+        return $this->layout_name;
+    }
+
     /**
      * 롼ƥŬ
      *
@@ -202,7 +238,6 @@ class SyL_Router
         $config_files = array();
         $config_files[] = SYL_APP_CONFIG_DIR . "/{$this->router_file_name}";
         if (!is_file($config_files[0])) {
-            SyL_Loggers::info("routers config file not found ({$config_files[0]})");
             return;
         }
 
@@ -212,12 +247,18 @@ class SyL_Router
             $action = str_replace('/', '\\/', $action); 
             if (preg_match('/^(' . $action . ')$/', $this->action_file)) {
                 if ($router['enableAction']) {
-                    $this->action_file  = $router['forwardAction'];
-                    $this->action_class = $this->createActionClass($this->action_file);
+                    if (isset($router['forwardAction']) && ($router['forwardAction'] !== '')) {
+                        $this->action_file  = $router['forwardAction'];
+                        $this->action_class = $this->createActionClass($this->action_file);
+                    }
                 }
                 if ($router['enableTemplate']) {
-                    $this->template_file = substr($router['forwardAction'], 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
+                    if (isset($router['forwardAction']) && ($router['forwardAction'] !== '')) {
+                        $this->template_file = substr($router['forwardAction'], 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
+                    }
                 }
+                $this->view_type   = $router['viewType'];
+                $this->layout_name = $router['layoutName'];
                 break;
             }
         }
@@ -226,7 +267,7 @@ class SyL_Router
     /**
      * 󥯥饹̾
      *
-     * @access public
+     * @access protected
      * @param string ե
      * @return string 󥯥饹̾
      */
