@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.10 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.10 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJson extends SyL_View
@@ -52,7 +52,7 @@ class SyL_ViewJson extends SyL_View
     function render()
     {
         // ƥĥפ򥻥å
-        $this->setContentType('application/json; charset=' . SYL_ENCODE_AJAX);
+        $this->setContentType('application/json; charset=' . SYL_ENCODE_JS);
 
         $values =& $this->getActionValues();
         // ѥ᡼ϡJson֥Ȥ򥻥å
@@ -60,9 +60,9 @@ class SyL_ViewJson extends SyL_View
             include_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilJson.php';
             $javascript = json_encode($values);
         } else {
-            mb_convert_variables(SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL, $values);
+            mb_convert_variables(SYL_ENCODE_JS, SYL_ENCODE_INTERNAL, $values);
             $javascript = json_encode($values);
-            $javascript = mb_convert_encoding($javascript, SYL_ENCODE_INTERNAL, SYL_ENCODE_AJAX);
+            $javascript = mb_convert_encoding($javascript, SYL_ENCODE_INTERNAL, SYL_ENCODE_JS);
         }
         // JavaScirpt
         $this->setRender($javascript);
