@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.13 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.14 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ set_magic_quotes_runtime(0);
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.13 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.14 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_File
@@ -151,7 +151,7 @@ class SyL_File
         case 'r': $type = 'Reader';   break;
         case 'w': $type = 'Writer';   break;
         case 'a': $type = 'Appender'; break;
-        default:  $type = ucfirst($type); break;
+        default:  trigger_error("[SyL error] Invalid type ({$type})", E_USER_ERROR);
         }
         $classname = "SyL_File{$type}";
         include_once dirname(__FILE__) . "/File/{$classname}.php";
@@ -207,7 +207,7 @@ class SyL_File
     /**
      * ե뤫ɤ߹
      *
-     * @access public
+     * @access protected
      * @return string ϥǡ or bool(false) ɤ߹߽λ
      */
     function read() {}
@@ -215,7 +215,7 @@ class SyL_File
     /**
      * ե˽Ϥ
      *
-     * @access public
+     * @access protected
      * @param string ϥå
      */
     function write($message) {}
@@ -223,22 +223,63 @@ class SyL_File
     /**
      * ե˽Ϥ˲Ԥղä
      *
-     * @access public
+     * @access protected
      * @param string ϥå
      */
     function writeln($message) {}
 
+    /**
+     * եΰϢ¹Ԥʥ֥Ⱥʳ
+     *
+     * @access protected
+     * @param string ϥå
+     * @return string եΥǡ
+     */
+    function process($message='')
+    {
+    }
+
+    /**
+     * եΰϢ¹Ԥʥ֥Ⱥޤ
+     *
+     * @static
+     * @access protected
+     * @param string ե
+     * @param string ե̾
+     * @param string եΥǡ
+     * @return string եΥǡ
+     */
+    function processAll($type, $resource_name, $message='')
+    {
+        $file =& SYL_File::factory($type, $resource_name);
+        switch (strtolower($type)) {
+        case 'r':
+            $message = $file->process();
+            break;
+        case 'w': 
+        case 'a': 
+            $file->process($message);
+            $message = null;
+            break;
+        }
+        return $message;
+    }
+
     /**
      * CSVեѤ
      *
      * @access public
+     * @param string ڤʸ
+     * @param string Ϥ
      */
-    function useCsv()
+    function useCsv($delimiter=',', $enclosure='')
     {
         if (is_resource($this->fp)) {
             trigger_error("[SyL error] `useCsv()' method use before `open()' method", E_USER_ERROR);
         }
         $this->csv = true;
+        $this->csv_delimiter = $delimiter;
+        $this->csv_enclosure = $enclosure;
     }
 
     /**
@@ -326,28 +367,6 @@ class SyL_File
         }
     }
 
-    /**
-     * CSVեζڤʸ򥻥åȤ
-     *
-     * @access public
-     * @param string ڤʸ
-     */
-    function setCsvDelimiter($csv_delimiter)
-    {
-        $this->csv_delimiter = $csv_delimiter;
-    }
-
-    /**
-     * CSVեΰϤҤ򥻥åȤ
-     *
-     * @access public
-     * @param string Ϥ
-     */
-    function setCsvEnclosure($csv_enclosure)
-    {
-        $this->csv_enclosure = $csv_enclosure;
-    }
-
     /**
      * ޥͤѤ
      *
